[llvm-commits] [llvm] r60506 - /llvm/trunk/lib/Transforms/Scalar/LoopStrengthReduce.cpp

Dale Johannesen dalej at apple.com
Wed Dec 3 12:56:13 PST 2008


Author: johannes
Date: Wed Dec  3 14:56:12 2008
New Revision: 60506

URL: http://llvm.org/viewvc/llvm-project?rev=60506&view=rev
Log:
Fix a misspelled function name.


Modified:
    llvm/trunk/lib/Transforms/Scalar/LoopStrengthReduce.cpp

Modified: llvm/trunk/lib/Transforms/Scalar/LoopStrengthReduce.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Transforms/Scalar/LoopStrengthReduce.cpp?rev=60506&r1=60505&r2=60506&view=diff

==============================================================================
--- llvm/trunk/lib/Transforms/Scalar/LoopStrengthReduce.cpp (original)
+++ llvm/trunk/lib/Transforms/Scalar/LoopStrengthReduce.cpp Wed Dec  3 14:56:12 2008
@@ -767,9 +767,9 @@
   return false;
 }
 
 /// MoveLoopVariantsToImediateField - Move any subexpressions from Val that are
 /// loop varying to the Imm operand.
-static void MoveLoopVariantsToImediateField(SCEVHandle &Val, SCEVHandle &Imm,
+static void MoveLoopVariantsToImmediateField(SCEVHandle &Val, SCEVHandle &Imm,
                                             Loop *L, ScalarEvolution *SE) {
   if (Val->isLoopInvariant(L)) return;  // Nothing to do.
   
@@ -793,7 +793,7 @@
   } else if (SCEVAddRecExpr *SARE = dyn_cast<SCEVAddRecExpr>(Val)) {
     // Try to pull immediates out of the start value of nested addrec's.
     SCEVHandle Start = SARE->getStart();
-    MoveLoopVariantsToImediateField(Start, Imm, L, SE);
+    MoveLoopVariantsToImmediateField(Start, Imm, L, SE);
     
     std::vector<SCEVHandle> Ops(SARE->op_begin(), SARE->op_end());
     Ops[0] = Start;
@@ -1183,7 +1183,7 @@
     // Move any loop variant operands from the offset field to the immediate
     // field of the use, so that we don't try to use something before it is
     // computed.
-    MoveLoopVariantsToImediateField(UsersToProcess.back().Base,
+    MoveLoopVariantsToImmediateField(UsersToProcess.back().Base,
                                     UsersToProcess.back().Imm, L, SE);
     assert(UsersToProcess.back().Base->isLoopInvariant(L) &&
            "Base value is not loop invariant!");
@@ -767,9 +767,9 @@
 }
 
-/// MoveLoopVariantsToImediateField - Move any subexpressions from Val that are
+/// MoveLoopVariantsToImmediateField - Move any subexpressions from Val that are
 /// loop varying to the Imm operand.





More information about the llvm-commits mailing list